Crate libreda_db[−][src]
This crate is a database for VLSI physical design. The core components are data structures for efficient representation of geometries and circuit netlists for chip layouts.
Core parts
- Two dimensional geometrical primitives (implemented by the
iron_shapescrate) NetlistsLayout
Re-exports
pub use iron_shapes; |
Modules
| index | Data structure for creating indices related to some other type. This is used to create handles for data stored in hash maps. |
| layout | Geometrical layout data structures. |
| netlist | Data structures for representation of circuit-level netlists. |
| prelude | The |
| property_storage | Container structs for user defined properties. |
| rc_string |
|