Module chip

Module chip 

Chip data structure holding netlist and layout together. Chip implements the L2NEdit trait and hence qualifies for representing netlists fused with a layout. Chip can also be used solely as a netlist structure or as a layout structure.

Structs

CellId
Circuit identifier.
CellInstId
Circuit instance identifier.
Chip
A netlist is the container of circuits.
Circuit
A circuit is defined by an interface (pins) and a content which consists of interconnected circuit instances.
CircuitInst
Instance of a circuit.
Net
A net represents an electric potential or a wire.
NetId
Net identifier.
Pin
Single bit wire pin.
PinId
Pin identifier.
PinInst
Instance of a pin.
PinInstId
Pin instance identifier.
Shape
Wrapper around a Geometry struct.
Shapes
Shapes<T> is a collection of Shape<T> structs. Each of the elements is assigned an index when inserted into the collection.

Enums

TerminalId
Either a pin or pin instance identifier.

Type Aliases

Area
Integer area type.
Coord
Integer coordinate type.
LayerId
ID for layers.
SInt
Default signed integer type.
ShapeId
Unique (across layout) identifier of a shape.
UInt
Default unsigned integer type.