Struct libreda_db::chip::CircuitInst
source · pub struct CircuitInst<C = Coord, U = ()>where
C: CoordinateType,{
name: Option<String>,
template_circuit_id: CellId,
parent_circuit_id: CellId,
properties: PropertyStore<String>,
user_data: U,
pins: Vec<PinInstId>,
transform: SimpleTransform<C>,
}Expand description
Instance of a circuit.
Template parameters:
U: User defined data.
Fields
name: Option<String>Name of the instance.
template_circuit_id: CellIdThe ID of the template circuit.
parent_circuit_id: CellIdThe ID of the parent circuit where this instance lives in.
properties: PropertyStore<String>Properties related to this instance.
user_data: UUser-defined data.
pins: Vec<PinInstId>List of pins of this instance.
transform: SimpleTransform<C>Transformation to put the cell to the right place an into the right scale/rotation.
Implementations
sourceimpl CircuitInst
impl CircuitInst
sourcefn get_transform(&self) -> &SimpleTransform<Coord>
fn get_transform(&self) -> &SimpleTransform<Coord>
Get the transformation that represents the location and orientation of this instance.
sourcefn set_transform(&mut self, tf: SimpleTransform<Coord>)
fn set_transform(&mut self, tf: SimpleTransform<Coord>)
Set the transformation that represents the location and orientation of this instance.