Struct libreda_db::chip::Net
source · pub struct Net {
pub name: Option<String>,
pub parent_id: CellId,
pub pins: FnvHashSet<PinId>,
pub pin_instances: FnvHashSet<PinInstId>,
pub net_shapes: FnvHashSet<ShapeId>,
}Expand description
A net represents an electric potential or a wire.
Fields
name: Option<String>Name of the net.
parent_id: CellIdParent circuit of the net.
pins: FnvHashSet<PinId>Pins connected to this net.
pin_instances: FnvHashSet<PinInstId>Pin instances connected to this net.
net_shapes: FnvHashSet<ShapeId>List of shapes in the layout that represent the physical net.