Module libreda_db::layout::algorithms
source · [−]Expand description
Collection of useful algorithms for layout processing.
Functions
Decompose a set of manhattanized polygons into non-overlapping horizontal rectangles. The polygons in form of an iterator over all the edges. A point is considered inside the polygon when the polygon wraps around it a non-zero number of times.