Module libreda_db::layout::cell[][src]

A cell is a container for geometric shapes and cell instances.

Structs

Cell

A Cell is a container for geometrical shapes organized on different layers. Additionally to the geometrical shapes a cell can also contain instances of other cells.

Type Definitions

CellReference

Mutable shared reference to a Cell.