LayoutStreamReader

Trait LayoutStreamReader 

pub trait LayoutStreamReader {
    type Error;

    // Required method
    fn read_layout<R: Read, L: LayoutEdit<Coord = i32>>(
        &self,
        reader: &mut R,
        layout: &mut L,
    ) -> Result<(), Self::Error>;
}
Trait for reading a layout from a byte stream.

Required Associated Types

type Error

Type of error that could happen while reading a layout.

Required Methods

fn read_layout<R: Read, L: LayoutEdit<Coord = i32>>( &self, reader: &mut R, layout: &mut L, ) -> Result<(), Self::Error>

Read a layout from a byte stream and populate the layout data structure.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors