Trait libreda_db::layout::io::LayoutStreamWriter[][src]

pub trait LayoutStreamWriter {
    type Error;
    fn write_layout<W: Write>(
        &self,
        writer: &mut W,
        layout: &Layout
    ) -> Result<(), Self::Error>; }

Trait for writing a layout to a byte stream.

Associated Types

type Error[src]

Type of error that could happen while writing a layout.

Loading content...

Required methods

fn write_layout<W: Write>(
    &self,
    writer: &mut W,
    layout: &Layout
) -> Result<(), Self::Error>
[src]

Write the layout data structure to a byte stream.

Loading content...

Implementors

Loading content...