Enum libreda_db::layout::prelude::PathEndType [−][src]
pub enum PathEndType<T> where
T: CoordinateType, {
Flat,
Extended(T, T),
Round,
}Expand description
Encoding for the type of the beginning and end of the path.
Variants
Beginning and end of path are not extended.
Define the extension length at the beginning and at the end of the path.
Path ends are round (approximately semi-circles).