Struct libreda_db::layout::prelude::ComplexTransform
pub struct ComplexTransform<T>where
T: CoordinateType,{
mirror: bool,
rotation: f64,
magnification: f64,
displacement: Vector<T>,
}Expand description
Transformation described by a mirroring at the x axis,
then a rotation around the origin, then a scaling, then a translation.
This transformation allows rotations by arbitrary angles.
Fields
mirror: boolrotation: f64magnification: f64displacement: Vector<T>Trait Implementations
impl<T> Clone for ComplexTransform<T>where
T: Clone + CoordinateType,
impl<T> Clone for ComplexTransform<T>where T: Clone + CoordinateType,
fn clone(&self) -> ComplexTransform<T>
fn clone(&self) -> ComplexTransform<T>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<T> Debug for ComplexTransform<T>where
T: Debug + CoordinateType,
impl<T> Debug for ComplexTransform<T>where T: Debug + CoordinateType,
impl<'de, T> Deserialize<'de> for ComplexTransform<T>where
T: CoordinateType + Deserialize<'de>,
impl<'de, T> Deserialize<'de> for ComplexTransform<T>where T: CoordinateType + Deserialize<'de>,
fn deserialize<__D>(
__deserializer: __D
) -> Result<ComplexTransform<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>( __deserializer: __D ) -> Result<ComplexTransform<T>, <__D as Deserializer<'de>>::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<T> PartialEq<ComplexTransform<T>> for ComplexTransform<T>where
T: PartialEq<T> + CoordinateType,
impl<T> PartialEq<ComplexTransform<T>> for ComplexTransform<T>where T: PartialEq<T> + CoordinateType,
fn eq(&self, other: &ComplexTransform<T>) -> bool
fn eq(&self, other: &ComplexTransform<T>) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl<T> Serialize for ComplexTransform<T>where
T: CoordinateType + Serialize,
impl<T> Serialize for ComplexTransform<T>where T: CoordinateType + Serialize,
fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>( &self, __serializer: __S ) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where __S: Serializer,
Serialize this value into the given Serde serializer. Read more