Struct libreda_db::layout::prelude::Matrix2dTransform
pub struct Matrix2dTransform<T>where
T: CoordinateType,{
matrix: Matrix2d<T>,
}Expand description
Description of a transformation in the euclidean plane by a 2x2 matrix A.
Transforming a point p is computed by the matrix product A*p.
Fields
matrix: Matrix2d<T>Implementations
impl<T> Matrix2dTransform<T>where
T: CoordinateType,
impl<T> Matrix2dTransform<T>where T: CoordinateType,
pub fn new(matrix: Matrix2d<T>) -> Matrix2dTransform<T>
pub fn new(matrix: Matrix2d<T>) -> Matrix2dTransform<T>
Create a new transform based on a matrix.
pub fn new_rotation90(angle: Angle) -> Matrix2dTransform<T>
pub fn new_rotation90(angle: Angle) -> Matrix2dTransform<T>
Create a rotation by an integer multiple of 90 degrees.
pub fn new_scaling(factor: T) -> Matrix2dTransform<T>
pub fn new_scaling(factor: T) -> Matrix2dTransform<T>
Create a scaling by a factor.
pub fn new_mirror_x() -> Matrix2dTransform<T>
pub fn new_mirror_x() -> Matrix2dTransform<T>
Mirror at the x-axis.
pub fn new_mirror_y() -> Matrix2dTransform<T>
pub fn new_mirror_y() -> Matrix2dTransform<T>
Mirror at the y-axis.
pub fn transform_point(&self, p: Point<T>) -> Point<T>
pub fn transform_point(&self, p: Point<T>) -> Point<T>
Apply the transformation to a single point.
pub fn to_matrix2d(&self) -> Matrix2d<T>
pub fn to_matrix2d(&self) -> Matrix2d<T>
Return the matrix describing this transformation.
pub fn try_invert(&self) -> Option<Matrix2dTransform<T>>
pub fn try_invert(&self) -> Option<Matrix2dTransform<T>>
Get the inverse transformation.