Struct libreda_db::layout::prelude::MultiPolygon
pub struct MultiPolygon<T> {
pub polygons: Vec<Polygon<T>, Global>,
}Expand description
A MultiPolygon is a list of polygons. There is no restrictions on the polygons (they can be
intersecting, empty, etc.).
Fields
polygons: Vec<Polygon<T>, Global>The list of polygons which defines the content of this multi polygon.
Implementations
impl<T> MultiPolygon<T>
impl<T> MultiPolygon<T>
pub fn new() -> MultiPolygon<T>
pub fn new() -> MultiPolygon<T>
Create an empty set of polygons.
pub fn from_polygons(polygons: Vec<Polygon<T>, Global>) -> MultiPolygon<T>
pub fn from_polygons(polygons: Vec<Polygon<T>, Global>) -> MultiPolygon<T>
Create a MultiPolygon from a vector of Polygons.
impl<T> MultiPolygon<T>where
T: Copy,
impl<T> MultiPolygon<T>where T: Copy,
pub fn all_edges_iter(&self) -> impl Iterator<Item = Edge<T>>
pub fn all_edges_iter(&self) -> impl Iterator<Item = Edge<T>>
Iterate over all edges of the polygons including holes.