Struct libreda_db::layout::prelude::Polygon
source · pub struct Polygon<T> {
pub exterior: SimplePolygon<T>,
pub interiors: Vec<SimplePolygon<T>>,
}Expand description
A polygon possibly with holes. The polygon is defined by a hull and a list of holes
which are both SimplePolygons.
Fields
exterior: SimplePolygon<T>The outer hull of the polygon.
interiors: Vec<SimplePolygon<T>>A list of holes in the polygon.
Implementations
sourceimpl<T> Polygon<T>
impl<T> Polygon<T>
sourcepub fn new_raw(exterior: Vec<Point<T>>) -> Polygon<T>
pub fn new_raw(exterior: Vec<Point<T>>) -> Polygon<T>
Create a new polygon from a sequence of points. Ordering of points is not normalized. This impacts the equality check.
sourcepub fn new_raw_with_holes<E, I>(exterior: E, holes: Vec<I>) -> Polygon<T>
pub fn new_raw_with_holes<E, I>(exterior: E, holes: Vec<I>) -> Polygon<T>
Create a new polygon from a hull and a list of holes. Ordering of points is not normalized. This impacts the equality check.
sourceimpl<T> Polygon<T>where
T: PartialOrd,
impl<T> Polygon<T>where
T: PartialOrd,
sourcepub fn new_with_holes<E, I>(exterior: E, holes: Vec<I>) -> Polygon<T>
pub fn new_with_holes<E, I>(exterior: E, holes: Vec<I>) -> Polygon<T>
Create a new polygon from a hull and a list of holes.
sourcepub fn normalize(&mut self)
pub fn normalize(&mut self)
Reorder vertices and holes to get the lexicographically smallest representation of this polygon. Does not change the orientations.
sourcepub fn normalized(self) -> Polygon<T>
pub fn normalized(self) -> Polygon<T>
Reorder vertices and holes to get the lexicographically smallest representation of this polygon. Does not change the orientations.
sourceimpl<T> Polygon<T>where
T: CoordinateType,
impl<T> Polygon<T>where
T: CoordinateType,
sourcepub fn convex_hull(&self) -> SimplePolygon<T>where
T: Ord,
pub fn convex_hull(&self) -> SimplePolygon<T>where
T: Ord,
Get the convex hull of the polygon.
Implements Andrew’s Monotone Chain algorithm. See: http://geomalgorithms.com/a10-_hull-1.html
sourcepub fn lower_left_vertex(&self) -> Point<T>
pub fn lower_left_vertex(&self) -> Point<T>
Get the vertex with lowest x-coordinate of the exterior polygon. Prefer lower y-coordinates to break ties.
Examples
use iron_shapes::polygon::Polygon;
use iron_shapes::point::Point;
let coords = vec![(0, 0), (1, 0), (-1, 2), (-1, 1)];
let poly = Polygon::new(coords);
assert_eq!(poly.lower_left_vertex(), Point::new(-1, 1));
sourcepub fn orientation<Area>(&self) -> Orientation
pub fn orientation<Area>(&self) -> Orientation
Get the orientation of the exterior polygon.
Examples
use iron_shapes::polygon::Polygon;
use iron_shapes::point::Point;
use iron_shapes::types::Orientation;
let coords = vec![(0, 0), (3, 0), (3, 1)];
let poly = Polygon::new(coords);
assert_eq!(poly.orientation::<i64>(), Orientation::CounterClockWise);