A rectangle which is oriented along the x an y axis and represented by its lower left and upper right corner.
Fields
lower_left: Point<T>Lower left corner of the rectangle.
upper_right: Point<T>Upper right corner of the rectangle.
Implementations
sourceimpl<T> Rect<T> where
T: PartialOrd<T> + Copy,
impl<T> Rect<T> where
T: PartialOrd<T> + Copy,
sourcepub fn new<C>(c1: C, c2: C) -> Rect<T> where
C: Into<Point<T>>,
pub fn new<C>(c1: C, c2: C) -> Rect<T> where
C: Into<Point<T>>,
Construct the bounding box of the two points. Order does not matter.
Examples
use iron_shapes::prelude::*;
// Create a rectangle based on two corner points.
let rect1 = Rect::new(Point::new(0, 0), Point::new(1, 2));
// Any type that implements `Into<Point<T>>` can be used for the corner points.
let rect2 = Rect::new((1, 2), (0, 0));
// Ordering of the corner points does not matter.
assert_eq!(rect1, rect2);
// Even though `(0, 0)` was passed as second argument it is recognized as lower left corner.
assert_eq!(rect2.lower_left(), Point::new(0, 0));sourceimpl<T> Rect<T> where
T: Copy,
impl<T> Rect<T> where
T: Copy,
sourcepub fn lower_left(&self) -> Point<T>
pub fn lower_left(&self) -> Point<T>
Get the lower left corner.
sourcepub fn upper_left(&self) -> Point<T>
pub fn upper_left(&self) -> Point<T>
Get the upper left corner.
sourcepub fn upper_right(&self) -> Point<T>
pub fn upper_right(&self) -> Point<T>
Get the upper right corner.
sourcepub fn lower_right(&self) -> Point<T>
pub fn lower_right(&self) -> Point<T>
Get the lower right corner.
sourceimpl<T> Rect<T> where
T: PartialOrd<T> + Copy,
impl<T> Rect<T> where
T: PartialOrd<T> + Copy,
sourcepub fn contains_point(&self, p: Point<T>) -> bool
pub fn contains_point(&self, p: Point<T>) -> bool
Check if rectangle contains the point. Inclusive boundaries.
Example
use iron_shapes::prelude::*;
let rect = Rect::new((0, 0), (10, 20));
// Contains point somewhere in the center.
assert!(rect.contains_point(Point::new(5, 5)));
// Also contains point on the boundaries.
assert!(rect.contains_point(Point::new(0, 0)));
// Does not contain point outside of the rectangle.
assert!(!rect.contains_point(Point::new(10, 21)));sourcepub fn contains_point_exclusive(&self, p: Point<T>) -> bool
pub fn contains_point_exclusive(&self, p: Point<T>) -> bool
Check if rectangle contains the point. Exclusive boundaries.
Example
use iron_shapes::prelude::*;
let rect = Rect::new((0, 0), (10, 20));
// Contains point somewhere in the center.
assert!(rect.contains_point_exclusive(Point::new(5, 5)));
// Does not contain points on boundaries.
assert!(!rect.contains_point_exclusive(Point::new(0, 0)));
// Does not contain point outside of the rectangle.
assert!(!rect.contains_point_exclusive(Point::new(10, 21)));sourcepub fn contains_rectangle(&self, other: &Rect<T>) -> bool
pub fn contains_rectangle(&self, other: &Rect<T>) -> bool
Check if rectangle contains other rectangle. Inclusive boundaries.
Example
use iron_shapes::prelude::*;
let outer = Rect::new((0, 0), (2, 2));
let inner = Rect::new((0, 0), (1, 1));
assert!(outer.contains_rectangle(&inner));
assert!(!inner.contains_rectangle(&outer));sourcepub fn contains_rectangle_exclusive(&self, other: &Rect<T>) -> bool
pub fn contains_rectangle_exclusive(&self, other: &Rect<T>) -> bool
Check if rectangle contains other rectangle. Exclusive boundaries.
Example
use iron_shapes::prelude::*;
let outer = Rect::new((0, 0), (3, 3));
let inner = Rect::new((1, 1), (2, 2));
assert!(outer.contains_rectangle_exclusive(&inner));
assert!(!inner.contains_rectangle_exclusive(&outer));
let not_inner = Rect::new((0, 0), (1, 1)); // This shares the boundary with `outer`.
assert!(!outer.contains_rectangle_exclusive(¬_inner));sourcepub fn touches(&self, other: &Rect<T>) -> bool
pub fn touches(&self, other: &Rect<T>) -> bool
Test if the both rectangles touch each other, i.e. if they either share a boundary or are overlapping.
sourcepub fn intersection(&self, other: &Rect<T>) -> Option<Rect<T>>
pub fn intersection(&self, other: &Rect<T>) -> Option<Rect<T>>
Compute the boolean intersection of two rectangles.
Example
use iron_shapes::prelude::*;
// Create two overlapping rectangles.
let a = Rect::new((0, 0), (2, 2));
let b = Rect::new((1, 1), (3, 3));
// Compute the intersection.
assert_eq!(a.intersection(&b), Some(Rect::new((1, 1), (2, 2))));
// Create a non-overlapping rectangle.
let c = Rect::new((100, 100), (200, 200));
// The intersection with a non-overlapping rectangle is `None`.
assert_eq!(a.intersection(&c), None);sourceimpl<T> Rect<T> where
T: Copy + PartialOrd<T>,
impl<T> Rect<T> where
T: Copy + PartialOrd<T>,