Struct libreda_db::layout::prelude::SimplePolygon [−][src]
pub struct SimplePolygon<T> where
T: CoordinateType, {
pub points: Vec<Point<T>, Global>,
}Expand description
A SimplePolygon is a polygon defined by vertices. It does not contain holes but can be
self-intersecting.
TODO: Implement Deref for accessing the vertices.
Fields
points: Vec<Point<T>, Global>Vertices of the polygon.
Implementations
Create a new polygon from a list of points.
The orientation of the points is normalized to counter-clock-wise.
Create a new polygon from a list of points. The points are taken as they are, without reordering or simplification.
Create a new simple polygon from a rectangle.
Create empty polygon without any vertices.
Get the convex hull of the polygon.
Implements Andrew’s Monotone Chain algorithm. See: http://geomalgorithms.com/a10-_hull-1.html
Get all exterior edges of the polygon.
Examples
use iron_shapes::simple_polygon::SimplePolygon;
use iron_shapes::edge::Edge;
let coords = vec![(0, 0), (1, 0)];
let poly = SimplePolygon::from(coords);
assert_eq!(poly.edges(), vec![Edge::new((0, 0), (1, 0)), Edge::new((1, 0), (0, 0))]);
Test if all edges are parallel to the x or y axis.
Get the vertex with lowest x-coordinate. Prefer lower y-coordinates to break ties.
Examples
use iron_shapes::simple_polygon::SimplePolygon;
use iron_shapes::point::Point;
let coords = vec![(0, 0), (1, 0), (-1, 2), (-1, 1)];
let poly = SimplePolygon::from(coords);
assert_eq!(poly.lower_left_vertex(), Point::new(-1, 1));
Get the orientation of the polygon, i.e. check if it is wound clock-wise or counter-clock-wise.
Examples
use iron_shapes::simple_polygon::SimplePolygon;
use iron_shapes::point::Point;
use iron_shapes::types::Orientation;
let coords = vec![(0, 0), (3, 0), (3, 1)];
let poly = SimplePolygon::from(coords);
assert_eq!(poly.orientation(), Orientation::CounterClockWise);