Struct libreda_db::layout::prelude::SimpleRPolygon [−][src]
pub struct SimpleRPolygon<T> where
T: CoordinateType, { /* fields omitted */ }Expand description
A SimpleRPolygon is a rectilinear polygon. It does not contain holes but can be self-intersecting.
The vertices are stored in an implicit format (one coordinate of two neighbour vertices is always the same
for rectilinear polygons). This reduces memory usage but has the drawback that edges must
alternate between horizontal and vertical. Vertices between two edges of the same orientation will
be dropped.
Implementations
Create new rectilinear polygon from points.
Returns None if the polygon defined by the points is not rectilinear.
use iron_shapes::simple_rpolygon::SimpleRPolygon;
let poly1 = SimpleRPolygon::try_new(vec![(0, 0), (1, 0), (1, 1), (0, 1)]);
assert!(poly1.is_some());
// A triangle cannot be rectilinear.
let poly1 = SimpleRPolygon::try_new(vec![(0, 0), (1, 0), (1, 1)]);
assert!(poly1.is_none());
Create empty polygon without any vertices.
Get the number of vertices.
Apply the transformation to this rectilinear polygon.
Convert to a SimplePolygon.
Get the convex hull of the polygon.
Implements Andrew’s Monotone Chain algorithm. See: http://geomalgorithms.com/a10-_hull-1.html
Get all exterior edges of the polygon.
Examples
use iron_shapes::simple_rpolygon::SimpleRPolygon;
use iron_shapes::redge::REdge;
let coords = vec![(0, 0), (1, 0), (1, 1), (0, 1)];
let poly = SimpleRPolygon::try_new(coords).unwrap();
let edges: Vec<_> = poly.edges().collect();
assert_eq!(edges, vec![
REdge::new((0, 0), (1, 0)),
REdge::new((1, 0), (1, 1)),
REdge::new((1, 1), (0, 1)),
REdge::new((0, 1), (0, 0)),
]);
Get the vertex with lowest x-coordinate. Prefer lower y-coordinates to break ties.
Examples
use iron_shapes::simple_rpolygon::SimpleRPolygon;
use iron_shapes::point::Point;
let coords = vec![(0, 0), (1, 0), (1, 1), (0, 1)];
let poly = SimpleRPolygon::try_new(coords).unwrap();
assert_eq!(poly.lower_left_vertex(), Point::new(0, 0));
Get the orientation of the polygon, i.e. check if it is wound clock-wise or counter-clock-wise.
Examples
use iron_shapes::simple_rpolygon::SimpleRPolygon;
use iron_shapes::point::Point;
use iron_shapes::types::Orientation;
let coords = vec![(0, 0), (1, 0), (1, 1), (0, 1)];
let poly = SimpleRPolygon::try_new(coords).unwrap();
assert_eq!(poly.orientation(), Orientation::CounterClockWise);
Create a copy of this polygon whose vertices are ordered in reversed order.