Module libreda_db::layout::shape_collection [−][src]
A shape collection represents a geometrical plane which contains geometrical shapes.
Structs
| Shape | Wrapper around a |
| Shapes |
|
A shape collection represents a geometrical plane which contains geometrical shapes.
| Shape | Wrapper around a |
| Shapes |
|