Struct libreda_db::layout::shape_collection::Shapes [−][src]
Shapes<T> is a collection of Shape<T> structs. Each of
the elements is assigned an index when inserted into the collection.
Implementations
impl<T: CoordinateType> Shapes<T>[src]
pub fn new_rc() -> Rc<Self>[src]
Create a new shapes object. It is not associated with any cell.
pub fn from_geometries<I: IntoIterator<Item = Geometry<T>>>(iter: I) -> Rc<Self>[src]
Create a new Shapes object and populate it with the geometries from the iterator.
pub fn insert<I: Into<Geometry<T>>>(&self, shape: I) -> Rc<Shape<T>>[src]
Add a shape to the collection.
pub fn remove_shape(&self, shape: &Shape<T>)[src]
Remove the shape from the collection if it exists.
TODO: What if a shape from another Shapes collection is passed here?
pub fn len(&self) -> usize[src]
Return number of shapes in this container.
pub fn is_empty(&self) -> bool[src]
Tell if there are not shapes stored in this container.
pub fn each_shape(&self) -> impl Iterator<Item = Rc<Shape<T>>> + '_[src]
Iterator over all shapes.
pub fn with_shape_iter<F, R>(&self, f: F) -> R where
F: FnOnce(Values<'_, Index<Shape<T>>, Rc<Shape<T>>>) -> R, [src]
F: FnOnce(Values<'_, Index<Shape<T>>, Rc<Shape<T>>>) -> R,
Iterate over all shapes.
pub fn for_each_shape<F>(&self, f: F) where
F: FnMut(&Rc<Shape<T>>), [src]
F: FnMut(&Rc<Shape<T>>),
Call a closure on each shape.
pub fn parent_cell(&self) -> Weak<Cell<T>>[src]
Get weak reference to the parent cell if there is any.