Module libreda_db::layout::util
source · [−]Expand description
Utility functions for dealing with layouts.
Traits
Helper functions for layouts.
Functions
Copy all layers (without their contents) from a source layout into a destination layout.
Copy a layer (without its content) from a source layout into a destination layout.
Copy the shapes on a specific layer from one cell into another cell.
Copy the shapes from all layers in a cell into another cell.