Function libreda_db::layout::util::copy_all_layers_preserve_ids
source · pub fn copy_all_layers_preserve_ids<LS, LT>(
target_layout: &mut LT,
source_layout: &LS
)where
LS: LayoutBase,
LT: LayoutEdit<LayerId = LS::LayerId>,Expand description
Copy all layers (without their contents) from a source layout into a destination layout and preserve
the layer IDs.
Source and target layout must have the same LayerId type.
Panics
Panics if a layer number or layer name already exists.