Function libreda_db::netlist::util::copy_pins
source · pub fn copy_pins<NS, ND>(
dest_netlist: &mut ND,
dest_cell: &ND::CellId,
source_netlist: &NS,
source_cell: &NS::CellId
)where
NS: NetlistBase,
ND: NetlistEdit,Expand description
Copy the pin definitoins from a cell to another cell in another netlist.
Panics
Panics if a pin name is already occupied at the destination cell.