Enum libreda_db::prelude::EdgeIntersection
source · [−]pub enum EdgeIntersection<TP, TO> where
TP: CoordinateType,
TO: CoordinateType, {
None,
Point(Point<TP>),
EndPoint(Point<TO>),
Overlap(Edge<TO>),
}Expand description
Return type for the edge-edge intersection functions. Stores all possible results of a edge to edge intersection.
Variants
None
No intersection.
Point(Point<TP>)
Intersection in a single point but not on an endpoint of an edge.
EndPoint(Point<TO>)
Intersection in an endpoint of an edge.
Overlap(Edge<TO>)
Full or partial overlap.