Enum libreda_db::prelude::REdgeIntersection
source · [−]pub enum REdgeIntersection<T> where
T: CoordinateType, {
None,
Point(Point<T>),
EndPoint(Point<T>),
Overlap(REdge<T>),
}Expand description
Return type for the edge-edge intersection functions. Stores all possible results of a edge to edge intersection.
Variants
None
No intersection.
Point(Point<T>)
Intersection in a single point but not on an endpoint of an edge.
EndPoint(Point<T>)
Intersection in an endpoint of an edge.
Overlap(REdge<T>)
Full or partial overlap.