Struct libreda_db::prelude::PointString
pub struct PointString<T> {
pub points: Vec<Point<T>, Global>,
}Expand description
A point string is a finite sequence of points.
TODO: Implement Deref for accessing the list of points.
Fields
points: Vec<Point<T>, Global>The points defining this point string.
Implementations
impl<T> PointString<T>
impl<T> PointString<T>
impl<T> PointString<T>where
T: Copy,
impl<T> PointString<T>where T: Copy,
pub fn new<I>(i: I) -> PointString<T>where
I: Into<PointString<T>>,
pub fn new<I>(i: I) -> PointString<T>where I: Into<PointString<T>>,
Create new point string by taking vertices from a type that implements Into<PointString<T>>.
pub fn edges(&self) -> impl Iterator<Item = Edge<T>>
pub fn edges(&self) -> impl Iterator<Item = Edge<T>>
Get the sequence of edges of the point string starting from the first point to the last.
Examples
use iron_shapes::point_string::PointString;
use iron_shapes::edge::Edge;
let coords = vec![(0, 0), (1, 0), (2, 0)];
let point_string = PointString::new(coords);
let edges: Vec<_> = point_string.edges().collect();
assert_eq!(edges, vec![Edge::new((0, 0), (1, 0)), Edge::new((1, 0), (2, 0))]);pub fn edges_reversed(&self) -> impl Iterator<Item = Edge<T>>
pub fn edges_reversed(&self) -> impl Iterator<Item = Edge<T>>
Same as edges but in reverse order.
Get the sequence of edges of the point string starting from the last point to the first.
Examples
use iron_shapes::point_string::PointString;
use iron_shapes::edge::Edge;
let coords = vec![(0, 0), (1, 0), (2, 0)];
let point_string = PointString::new(coords);
let edges: Vec<_> = point_string.edges_reversed().collect();
assert_eq!(edges, vec![Edge::new((2, 0), (1, 0)), Edge::new((1, 0), (0, 0))]);impl<T> PointString<T>where
T: Copy + Sub<T, Output = T> + NumCast,
impl<T> PointString<T>where T: Copy + Sub<T, Output = T> + NumCast,
pub fn path_length<F>(&self) -> Fwhere
F: Float,
pub fn path_length<F>(&self) -> Fwhere F: Float,
Compute geometrical length of the path defined by the point string.
Examples
use iron_shapes::point_string::PointString;
let coords = vec![(0, 0), (1, 0), (2, 0)];
let point_string = PointString::new(coords);
assert_eq!(point_string.path_length::<f64>(), 2.0);Trait Implementations
impl<T> Clone for PointString<T>where
T: Clone,
impl<T> Clone for PointString<T>where T: Clone,
fn clone(&self) -> PointString<T>
fn clone(&self) -> PointString<T>
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl<T> Debug for PointString<T>where
T: Debug,
impl<T> Debug for PointString<T>where T: Debug,
impl<'de, T> Deserialize<'de> for PointString<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for PointString<T>where T: Deserialize<'de>,
fn deserialize<__D>(
__deserializer: __D
) -> Result<PointString<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>( __deserializer: __D ) -> Result<PointString<T>, <__D as Deserializer<'de>>::Error>where __D: Deserializer<'de>,
impl<I, T, P> From<I> for PointString<T>where
T: Copy,
I: IntoIterator<Item = P>,
Point<T>: From<P>,
impl<I, T, P> From<I> for PointString<T>where T: Copy, I: IntoIterator<Item = P>, Point<T>: From<P>,
Create a point string from something that can be turned into an iterator of values convertible to Points.
fn from(iter: I) -> PointString<T>
fn from(iter: I) -> PointString<T>
impl<T, P> FromIterator<P> for PointString<T>where
T: Copy,
P: Into<Point<T>>,
impl<T, P> FromIterator<P> for PointString<T>where T: Copy, P: Into<Point<T>>,
Create a point string from a iterator of values convertible to Points.
fn from_iter<I>(iter: I) -> PointString<T>where
I: IntoIterator<Item = P>,
fn from_iter<I>(iter: I) -> PointString<T>where I: IntoIterator<Item = P>,
impl<T> Hash for PointString<T>where
T: Hash,
impl<T> Hash for PointString<T>where T: Hash,
impl<T> MapPointwise<T> for PointString<T>where
T: Copy,
impl<T> MapPointwise<T> for PointString<T>where T: Copy,
impl<T> PartialEq<PointString<T>> for PointString<T>where
T: PartialEq<T>,
impl<T> PartialEq<PointString<T>> for PointString<T>where T: PartialEq<T>,
fn eq(&self, other: &PointString<T>) -> bool
fn eq(&self, other: &PointString<T>) -> bool
self and other values to be equal, and is used
by ==.impl<T> Serialize for PointString<T>where
T: Serialize,
impl<T> Serialize for PointString<T>where T: Serialize,
fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>( &self, __serializer: __S ) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where __S: Serializer,
impl<T> TryBoundingBox<T> for PointString<T>where
T: Copy + PartialOrd<T>,
impl<T> TryBoundingBox<T> for PointString<T>where T: Copy + PartialOrd<T>,
fn try_bounding_box(&self) -> Option<Rect<T>>
fn try_bounding_box(&self) -> Option<Rect<T>>
Compute the bounding box of all the points in this string.
Returns None if the string is empty.
Examples
use iron_shapes::point_string::PointString;
use iron_shapes::traits::TryBoundingBox;
use iron_shapes::rect::Rect;
let coords = vec![(0, 0), (1, 0), (2, 1), (-1, -3)];
let point_string = PointString::new(coords);
assert_eq!(point_string.try_bounding_box(), Some(Rect::new((2, 1), (-1, -3))));