Trait libreda_db::prelude::CoordinateType
pub trait CoordinateType: Num + Copy + PartialOrd<Self> + Sized { }Expand description
Trait for types that can be used as coordinates in the euclidean plane. In practice this are integers, floats and possible rational numbers.