Struct libreda_db::property_storage::PropertyStore [−][src]
Look-up table for property values.
Implementations
Insert a property. Returns the old property value if there was already a property stored under this key.
Get a property value by the property key.
Check if the key is contained in this property store.