Struct libreda_db::rc_string::RcString [−][src]
pub struct RcString { /* fields omitted */ }Expand description
Resource counted string, used for names.
RcStrings can be efficiently cloned.
Implementations
Methods from Deref<Target = String>
Extracts a string slice containing the entire String.
Examples
Basic usage:
let s = String::from("foo");
assert_eq!("foo", s.as_str());Returns this String’s capacity, in bytes.
Examples
Basic usage:
let s = String::with_capacity(10);
assert!(s.capacity() >= 10);Returns the length of this String, in bytes, not chars or
graphemes. In other words, it might not be what a human considers the
length of the string.
Examples
Basic usage:
let a = String::from("foo");
assert_eq!(a.len(), 3);
let fancy_f = String::from("ƒoo");
assert_eq!(fancy_f.len(), 4);
assert_eq!(fancy_f.chars().count(), 3);Trait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more