Struct libreda_db::reference_access::NetRef
source · [−]pub struct NetRef<'a, N: NetlistBase + ?Sized> { /* private fields */ }Expand description
A reference to a net. This is just a wrapper around a netlist and a net ID.
Implementations
sourceimpl<'a, N: NetlistBase> NetRef<'a, N>
impl<'a, N: NetlistBase> NetRef<'a, N>
sourcepub fn each_pin(&self) -> impl Iterator<Item = PinRef<'a, N>> + '_
pub fn each_pin(&self) -> impl Iterator<Item = PinRef<'a, N>> + '_
Iterate over each pin attached to this net.
sourcepub fn each_pin_instance(&self) -> impl Iterator<Item = PinInstRef<'a, N>> + '_
pub fn each_pin_instance(&self) -> impl Iterator<Item = PinInstRef<'a, N>> + '_
Iterate over each pin instance attached to this net.
sourcepub fn each_terminal(&self) -> impl Iterator<Item = TerminalRef<'a, N>> + '_
pub fn each_terminal(&self) -> impl Iterator<Item = TerminalRef<'a, N>> + '_
Iterate over terminal attached to this net.
sourcepub fn each_driver(&self) -> impl Iterator<Item = TerminalRef<'a, N>> + '_
pub fn each_driver(&self) -> impl Iterator<Item = TerminalRef<'a, N>> + '_
Iterate over all terminals that drive the net. This should usually be one.
Returns the pins that are marked as inputs and pin instances marked as outputs.
Skips InOut terminals.
sourcepub fn each_sink(&self) -> impl Iterator<Item = TerminalRef<'a, N>> + '_
pub fn each_sink(&self) -> impl Iterator<Item = TerminalRef<'a, N>> + '_
Iterate over all terminals that drive the net. This should usually be one.
Returns the pins that are marked as inputs and pin instances marked as outputs.
Skips InOut terminals.