pub struct CellRef<H: HierarchyBase> {
pub(super) base: RwRefAccess<H>,
pub(super) id: H::CellId,
}Expand description
A reference to a cell. This is just a wrapper around a netlist and a cell ID.
Fields
base: RwRefAccess<H>Reference to the parent data structure.
id: H::CellIdID of the corresponding cell.
Implementations
sourceimpl<H: HierarchyBase> CellRef<H>
impl<H: HierarchyBase> CellRef<H>
sourcepub fn base(&self) -> &RwRefAccess<H>
pub fn base(&self) -> &RwRefAccess<H>
Access the base structure.
sourcepub fn each_cell_instance_id(&self) -> Vec<H::CellInstId>
pub fn each_cell_instance_id(&self) -> Vec<H::CellInstId>
Get the IDs of all cell instances in this cell.
sourcepub fn each_cell_instance(&self) -> Vec<CellInstRef<H>>
pub fn each_cell_instance(&self) -> Vec<CellInstRef<H>>
Get all cell instances inside this cell.
sourcepub fn cell_instance_by_name(&self, name: &str) -> Option<CellInstRef<H>>
pub fn cell_instance_by_name(&self, name: &str) -> Option<CellInstRef<H>>
Find a child instance by its name.
sourcepub fn each_reference_id(&self) -> Vec<H::CellInstId>
pub fn each_reference_id(&self) -> Vec<H::CellInstId>
Get the IDs of all instances of this cell.
sourcepub fn each_reference(&self) -> Vec<CellInstRef<H>>
pub fn each_reference(&self) -> Vec<CellInstRef<H>>
Get all instances of this cell.
sourcepub fn each_cell_dependency(&self) -> Vec<CellRef<H>>
pub fn each_cell_dependency(&self) -> Vec<CellRef<H>>
Get all dependencies of this cell.
sourcepub fn each_dependent_cell(&self) -> Vec<CellRef<H>>
pub fn each_dependent_cell(&self) -> Vec<CellRef<H>>
Get all cells that directly depend on this cell.
sourcepub fn num_child_instances(&self) -> usize
pub fn num_child_instances(&self) -> usize
Get the number of cell instances inside the cell.