Module libreda_db::technology
source · Expand description
Traits and datastructures for the representation of technology related properties, especially design rules.
Modules
- Definition of the metal layer stack as it is needed for routers.
- Helper to include all traits and structures related to design rules and technology descriptions.
- Traits that define how certain design rules are represented.