pub trait RoutingLayerStack {
    type LayerId: Clone + Eq;
    fn layer_stack(&self) -> Vec<RoutingLayerType<Self::LayerId>>;

    fn routing_layer_stack(&self) -> Vec<Self::LayerId> { ... }
fn via_layer_stack(&self) -> Vec<Self::LayerId> { ... } }
Define standardized access for routing and via layers.

Associated Types

Identifier type for layers.

Required methods

Get the stack of routing and via layers in process order.

Provided methods

Get the stack of routing metal layers in process order.

Get the stack of via layers in process order.

Implementors