MinimumSpacing

Trait MinimumSpacing 

pub trait MinimumSpacing: DistanceRuleBase {
    // Required methods
    fn min_spacing_absolute(
        &self,
        layer: &Self::LayerId,
    ) -> Option<Self::Distance>;
    fn min_spacing(
        &self,
        layer: &Self::LayerId,
        run_length: Self::Distance,
        width: Self::Distance,
    ) -> Option<Self::Distance>;
}
Minimum spacing rules between shapes on the same layer.

Required Methods

fn min_spacing_absolute(&self, layer: &Self::LayerId) -> Option<Self::Distance>

Absolute minimum spacing between two shapes on the layer.

fn min_spacing( &self, layer: &Self::LayerId, run_length: Self::Distance, width: Self::Distance, ) -> Option<Self::Distance>

Minimum spacing between two shapes on the layer dependent on the geometries.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors