RoutingRules

Trait RoutingRules 

pub trait RoutingRules:
    PreferredRoutingDirection
    + DefaultWidth
    + MinimumSpacing
    + MinimumWidth {
    // Required method
    fn default_pitch(
        &self,
        layer: &Self::LayerId,
    ) -> Option<(Self::Distance, Self::Distance)>;

    // Provided method
    fn default_pitch_preferred_direction(
        &self,
        layer: &Self::LayerId,
    ) -> Option<Self::Distance> { ... }
}
Rules commonly used for routing.

Required Methods

fn default_pitch( &self, layer: &Self::LayerId, ) -> Option<(Self::Distance, Self::Distance)>

Get the default routing pitch on this layer for x and y directions.

Provided Methods

fn default_pitch_preferred_direction( &self, layer: &Self::LayerId, ) -> Option<Self::Distance>

Get the default routing pitch for wires with the preferred routing direction. Return None if no default pitch or no routing direction is defined for this layer.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors