Module libreda_db::chip
source · Expand description
Structs
- Circuit identifier.
- Circuit instance identifier.
- A netlist is the container of circuits.
- A circuit is defined by an interface (pins) and a content which consists of interconnected circuit instances.
- Instance of a circuit.
- A net represents an electric potential or a wire.
- Net identifier.
- Single bit wire pin.
- Pin identifier.
- Instance of a pin.
- Pin instance identifier.
- Wrapper around a
Geometrystruct. Shapes<T>is a collection ofShape<T>structs. Each of the elements is assigned an index when inserted into the collection.
Enums
- Either a pin or pin instance identifier.
Type Aliases
- Integer area type.
- Integer coordinate type.
- ID for layers.
- Default signed integer type.
- Unique (across layout) identifier of a shape.
- Default unsigned integer type.