Module libreda_db::layout::cell [−][src]
A cell is a container for geometric shapes and cell instances.
Structs
| Cell | A |
Type Definitions
| CellReference | Mutable shared reference to a |
A cell is a container for geometric shapes and cell instances.
| Cell | A |
| CellReference | Mutable shared reference to a |