Struct libreda_db::layout::hashmap_layout::Cell [−][src]
A Cell is a container for geometrical shapes organized on different layers.
Additionally to the geometrical shapes a cell can also contain instances of other cells.