pub trait LayoutStreamReader {
type Error;
// Required method
fn read_layout<R: Read, L: LayoutEdit<Coord = i32>>(
&self,
reader: &mut R,
layout: &mut L,
) -> Result<(), Self::Error>;
}Expand description
Trait for reading a layout from a byte stream.
Required Associated Types
Required Methods
Sourcefn read_layout<R: Read, L: LayoutEdit<Coord = i32>>(
&self,
reader: &mut R,
layout: &mut L,
) -> Result<(), Self::Error>
fn read_layout<R: Read, L: LayoutEdit<Coord = i32>>( &self, reader: &mut R, layout: &mut L, ) -> Result<(), Self::Error>
Read a layout from a byte stream and populate the layout data structure.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".