pub trait LayoutStreamReader {
    type Error;
    fn read_layout<R: Read, L: LayoutEdit<Coord = i32>>(
        &self,
        reader: &mut R,
        layout: &mut L
    ) -> Result<(), Self::Error>; }
Trait for reading a layout from a byte stream.

Associated Types

Type of error that could happen while reading a layout.

Required methods

Read a layout from a byte stream and populate the layout data structure.

Implementors