Struct libreda_db::layout::prelude::ComplexTransform [−][src]
pub struct ComplexTransform<T> where
T: CoordinateType, { /* fields omitted */ }Expand description
Transformation described by a mirroring at the x axis,
then a rotation around the origin, then a scaling, then a translation.
This transformation allows rotations by arbitrary angles.