Struct libreda_db::layout::prelude::Matrix2dTransform [−][src]
pub struct Matrix2dTransform<T> where
T: CoordinateType, { /* fields omitted */ }Expand description
Description of a transformation in the euclidean plane by a 2x2 matrix A.
Transforming a point p is computed by the matrix product A*p.
Implementations
Create a new transform based on a matrix.
Create a rotation by an integer multiple of 90 degrees.
Create a scaling by a factor.
Mirror at the x-axis.
Mirror at the y-axis.
Apply the transformation to a single point.
Return the matrix describing this transformation.
Get the inverse transformation.