Struct libreda_db::layout::prelude::Polygon [−][src]
pub struct Polygon<T> where
T: CoordinateType, {
pub exterior: SimplePolygon<T>,
pub interiors: Vec<SimplePolygon<T>, Global>,
}Expand description
A polygon possibly with holes. The polygon is defined by a hull and a list of holes
which are both SimplePolygons.
Fields
exterior: SimplePolygon<T>The outer hull of the polygon.
interiors: Vec<SimplePolygon<T>, Global>A list of holes in the polygon.
Implementations
Create a new polygon from a sequence of points.
pub fn new_with_holes<E, I>(exterior: E, holes: Vec<I, Global>) -> Polygon<T> where
E: Into<SimplePolygon<T>>,
I: Into<SimplePolygon<T>>,
pub fn new_with_holes<E, I>(exterior: E, holes: Vec<I, Global>) -> Polygon<T> where
E: Into<SimplePolygon<T>>,
I: Into<SimplePolygon<T>>,
Create a new polygon from a hull and a list of holes.
Get the convex hull of the polygon.
Implements Andrew’s Monotone Chain algorithm. See: http://geomalgorithms.com/a10-_hull-1.html
Get the vertex with lowest x-coordinate of the exterior polygon. Prefer lower y-coordinates to break ties.
Examples
use iron_shapes::polygon::Polygon;
use iron_shapes::point::Point;
let coords = vec![(0, 0), (1, 0), (-1, 2), (-1, 1)];
let poly = Polygon::new(coords);
assert_eq!(poly.lower_left_vertex(), Point::new(-1, 1));
Get the orientation of the exterior polygon.
Examples
use iron_shapes::polygon::Polygon;
use iron_shapes::point::Point;
use iron_shapes::types::Orientation;
let coords = vec![(0, 0), (3, 0), (3, 1)];
let poly = Polygon::new(coords);
assert_eq!(poly.orientation(), Orientation::CounterClockWise);