Trait libreda_db::layout::traits::LayoutEdit

source ·
pub trait LayoutEdit: LayoutBase + HierarchyEdit {
    // Required methods
    fn create_layer(&mut self, index: UInt, datatype: UInt) -> Self::LayerId;
    fn create_layer_with_id(
        &mut self,
        layer_id: Self::LayerId,
        index: UInt,
        datatype: UInt
    ) -> Result<(), ()>;
    fn set_layer_name(
        &mut self,
        layer: &Self::LayerId,
        name: Option<Self::NameType>
    ) -> Option<Self::NameType>;
    fn insert_shape(
        &mut self,
        parent_cell: &Self::CellId,
        layer: &Self::LayerId,
        geometry: Geometry<Self::Coord>
    ) -> Self::ShapeId;
    fn remove_shape(
        &mut self,
        shape_id: &Self::ShapeId
    ) -> Option<Geometry<Self::Coord>>;
    fn replace_shape(
        &mut self,
        shape_id: &Self::ShapeId,
        geometry: Geometry<Self::Coord>
    ) -> Geometry<Self::Coord>;
    fn set_transform(
        &mut self,
        cell_inst: &Self::CellInstId,
        tf: SimpleTransform<Self::Coord>
    );

    // Provided methods
    fn set_dbu(&mut self, dbu: Self::Coord) { ... }
    fn set_shape_property(
        &mut self,
        shape: &Self::ShapeId,
        key: Self::NameType,
        value: PropertyValue
    ) { ... }
}
Trait for layouts that support editing.

Required Methods

source

fn create_layer(&mut self, index: UInt, datatype: UInt) -> Self::LayerId

Create a new layer. Use set_layer_name() to define a name.

source

fn create_layer_with_id( &mut self, layer_id: Self::LayerId, index: UInt, datatype: UInt ) -> Result<(), ()>

Create a new layer with a specific ID. This is used to clone layer-stacks between layouts while preserving their IDs. Returns an Err when the ID already exists.

source

fn set_layer_name( &mut self, layer: &Self::LayerId, name: Option<Self::NameType> ) -> Option<Self::NameType>

Set the name of a layer or clear the layer name when passing None. This method should not change the ID of the layer. Returns the previous name of the layer.

source

fn insert_shape( &mut self, parent_cell: &Self::CellId, layer: &Self::LayerId, geometry: Geometry<Self::Coord> ) -> Self::ShapeId

Insert a geometric shape into the parent cell.

source

fn remove_shape( &mut self, shape_id: &Self::ShapeId ) -> Option<Geometry<Self::Coord>>

Remove shape from the parent cell.

source

fn replace_shape( &mut self, shape_id: &Self::ShapeId, geometry: Geometry<Self::Coord> ) -> Geometry<Self::Coord>

Replace the geometry of a shape.

source

fn set_transform( &mut self, cell_inst: &Self::CellInstId, tf: SimpleTransform<Self::Coord> )

Set the geometric transform that describes the location of a cell instance relative to its parent.

Provided Methods

source

fn set_dbu(&mut self, dbu: Self::Coord)

Set the distance unit used in this layout in ‘pixels per micron’.

source

fn set_shape_property( &mut self, shape: &Self::ShapeId, key: Self::NameType, value: PropertyValue )

Set a property of a shape.

Object Safety

This trait is not object safe.

Implementations on Foreign Types

source

impl<T> LayoutEdit for &mut T
where T: LayoutEdit,

source

fn set_shape_property( &mut self, shape: &Self::ShapeId, key: Self::NameType, value: PropertyValue )

source

fn create_layer_with_id( &mut self, layer_id: Self::LayerId, index: UInt, datatype: UInt ) -> Result<(), ()>

source

fn set_layer_name( &mut self, layer: &Self::LayerId, name: Option<Self::NameType> ) -> Option<Self::NameType>

source

fn replace_shape( &mut self, shape_id: &Self::ShapeId, geometry: Geometry<Self::Coord> ) -> Geometry<Self::Coord>

source

fn set_dbu(&mut self, dbu: Self::Coord)

source

fn create_layer(&mut self, index: UInt, datatype: UInt) -> Self::LayerId

source

fn insert_shape( &mut self, parent_cell: &Self::CellId, layer: &Self::LayerId, geometry: Geometry<Self::Coord> ) -> Self::ShapeId

source

fn set_transform( &mut self, cell_inst: &Self::CellInstId, tf: SimpleTransform<Self::Coord> )

source

fn remove_shape( &mut self, shape_id: &Self::ShapeId ) -> Option<Geometry<Self::Coord>>

source

impl<T> LayoutEdit for Box<T>
where T: LayoutEdit,

source

fn insert_shape( &mut self, parent_cell: &Self::CellId, layer: &Self::LayerId, geometry: Geometry<Self::Coord> ) -> Self::ShapeId

source

fn set_dbu(&mut self, dbu: Self::Coord)

source

fn create_layer(&mut self, index: UInt, datatype: UInt) -> Self::LayerId

source

fn create_layer_with_id( &mut self, layer_id: Self::LayerId, index: UInt, datatype: UInt ) -> Result<(), ()>

source

fn replace_shape( &mut self, shape_id: &Self::ShapeId, geometry: Geometry<Self::Coord> ) -> Geometry<Self::Coord>

source

fn remove_shape( &mut self, shape_id: &Self::ShapeId ) -> Option<Geometry<Self::Coord>>

source

fn set_transform( &mut self, cell_inst: &Self::CellInstId, tf: SimpleTransform<Self::Coord> )

source

fn set_shape_property( &mut self, shape: &Self::ShapeId, key: Self::NameType, value: PropertyValue )

source

fn set_layer_name( &mut self, layer: &Self::LayerId, name: Option<Self::NameType> ) -> Option<Self::NameType>

Implementors

source

impl LayoutEdit for Chip<Coord>

source

impl<'a, T, U> LayoutEdit for Undo<'a, T, U>
where T: LayoutEdit + 'static, U: From<LayoutUndoOp<T>> + From<HierarchyUndoOp<T>>,

source

impl<L> LayoutEdit for RegionSearchAdapter<L>
where L: LayoutEdit, L::Coord: PrimInt + Signed + Debug,

source

impl<L: LayoutEdit> LayoutEdit for DBPerf<L>