Trait libreda_db::netlist::util::NetlistUtil[−][src]

pub trait NetlistUtil: NetlistBase {
    fn is_constant_net(&self, net: &Self::NetId) -> bool { ... }
fn nets_of_cell_instance(
        &self,
        inst: &Self::CellInstId
    ) -> Box<dyn Iterator<Item = Self::NetId>> { ... } }
Non-modifying utility functions for netlists. Import the this trait to use the utility functions all types that implement the NetlistBase trait.

Provided methods

Check if the net is either the constant LOW or HIGH.

Get all nets that are connected to the circuit instance.

Implementors