Enum libreda_db::prelude::EdgeIntersection [−][src]
pub enum EdgeIntersection<TP, TO> where
TP: CoordinateType,
TO: CoordinateType, {
None,
Point(Point<TP>),
EndPoint(Point<TO>),
Overlap(Edge<TO>),
}Expand description
Return type for the edge-edge intersection functions. Stores all possible results of a edge to edge intersection.
Variants
No intersection.
Point(Point<TP>)Intersection in a single point but not on an endpoint of an edge.
Tuple Fields of Point
0: Point<TP>EndPoint(Point<TO>)Intersection in an endpoint of an edge.
Tuple Fields of EndPoint
0: Point<TO>Overlap(Edge<TO>)Full or partial overlap.
Tuple Fields of Overlap
0: Edge<TO>Trait Implementations
impl<TP, TO> Clone for EdgeIntersection<TP, TO> where
TP: Clone + CoordinateType,
TO: Clone + CoordinateType,
impl<TP, TO> Clone for EdgeIntersection<TP, TO> where
TP: Clone + CoordinateType,
TO: Clone + CoordinateType,
impl<TP, TO> Debug for EdgeIntersection<TP, TO> where
TP: Debug + CoordinateType,
TO: Debug + CoordinateType,
impl<TP, TO> Debug for EdgeIntersection<TP, TO> where
TP: Debug + CoordinateType,
TO: Debug + CoordinateType,
impl<TP, TO> PartialEq<EdgeIntersection<TP, TO>> for EdgeIntersection<TP, TO> where
TP: PartialEq<TP> + CoordinateType,
TO: PartialEq<TO> + CoordinateType,
impl<TP, TO> PartialEq<EdgeIntersection<TP, TO>> for EdgeIntersection<TP, TO> where
TP: PartialEq<TP> + CoordinateType,
TO: PartialEq<TO> + CoordinateType,
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<TP, TO> Copy for EdgeIntersection<TP, TO> where
TP: Copy + CoordinateType,
TO: Copy + CoordinateType,
impl<TP, TO> Eq for EdgeIntersection<TP, TO> where
TP: Eq + CoordinateType,
TO: Eq + CoordinateType,
impl<TP, TO> StructuralEq for EdgeIntersection<TP, TO> where
TP: CoordinateType,
TO: CoordinateType,
impl<TP, TO> StructuralPartialEq for EdgeIntersection<TP, TO> where
TP: CoordinateType,
TO: CoordinateType,