Struct libreda_db::property_storage::PropertyStore [−][src]
Look-up table for property values.
Implementations
impl<K: Hash + Eq> PropertyStore<K>[src]
pub fn new() -> Self[src]
Create an empty property store.
pub fn insert<V: Into<PropertyValue>>(
&mut self,
key: K,
value: V
) -> Option<PropertyValue>[src]
&mut self,
key: K,
value: V
) -> Option<PropertyValue>
Insert a property. Returns the old property value if there was already a property stored under this key.
pub fn get<Q: ?Sized>(&self, key: &Q) -> Option<&PropertyValue> where
K: Borrow<Q>,
Q: Eq + Hash, [src]
K: Borrow<Q>,
Q: Eq + Hash,
Get a property value by the property key.
pub fn contains_key<Q: ?Sized>(&self, key: &Q) -> bool where
K: Borrow<Q>,
Q: Eq + Hash, [src]
K: Borrow<Q>,
Q: Eq + Hash,
Check if the key is contained in this property store.
pub fn get_string<Q: ?Sized>(&self, key: &Q) -> Option<&Rc<String>> where
K: Borrow<Q>,
Q: Eq + Hash, [src]
K: Borrow<Q>,
Q: Eq + Hash,
Get a string property value by key.
If the property value is not a string None is returned.