Trait libreda_db::technology::rules::RoutingRules

source ·
pub trait RoutingRules: PreferredRoutingDirection + DefaultWidth + MinimumSpacing + MinimumWidth {
    // Required method
    fn default_pitch(
        &self,
        layer: &Self::LayerId
    ) -> Option<(Self::Distance, Self::Distance)>;

    // Provided method
    fn default_pitch_preferred_direction(
        &self,
        layer: &Self::LayerId
    ) -> Option<Self::Distance> { ... }
}
Rules commonly used for routing.

Required Methods

source

fn default_pitch( &self, layer: &Self::LayerId ) -> Option<(Self::Distance, Self::Distance)>

Get the default routing pitch on this layer for x and y directions.

Provided Methods

source

fn default_pitch_preferred_direction( &self, layer: &Self::LayerId ) -> Option<Self::Distance>

Get the default routing pitch for wires with the preferred routing direction. Return None if no default pitch or no routing direction is defined for this layer.

Object Safety

This trait is not object safe.

Implementors